@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,7 +85,7 @@ public class ContactPictureServlet extends OnlinePublicationServlet {
     private static final String SITE = "site";
     private static final String CONTACT_ID = "contactId";
 
-    private static final Log LOG = LogFactory.getLog(ContactPictureServlet.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactPictureServlet.class));
     
     private static OXMFPublicationService contactPublisher = null;
     
@@ -105,7 +105,7 @@ public class ContactPictureServlet extends OnlinePublicationServlet {
         try {
             final Context ctx = contexts.getContext(Integer.parseInt(args.get(CONTEXTID)));
             final Publication publication = contactPublisher.getPublication(ctx, args.get(SITE));
-            if (publication == null) {
+            if (publication == null || !publication.isEnabled()) {
                 resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
                 resp.getWriter().println("Don't know site " + args.get(SITE));
                 return;
@@ -114,6 +114,10 @@ public class ContactPictureServlet extends OnlinePublicationServlet {
                 return;
             }
             
+            if (!checkPublicationPermission(publication, resp)) {
+                return;
+            }
+            
             final int folderId = Integer.parseInt(publication.getEntityId());
             final int contactId = Integer.parseInt(args.get(CONTACT_ID));
             
