@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,12 +60,16 @@ public class FormStrings implements LocalizableStrings {
 
     public static final String FORM_LABEL_SITE = "Site";
 
-    public static final String FORM_LABEL_TEMPLATE = "Template (optional)";
+    public static final String FORM_LABEL_TEMPLATE = "Apply a Template (optional)";
 
     public static final String FORM_LABEL_PROTECTED = "Add cipher code";
 
     public static final String FORM_LABEL_LINK = "URL";
 
+    public static final String TARGET_NAME_CONTACTS = "OXMF Contacts";
+
+    public static final String TARGET_NAME_INFOSTORE = "OXMF Infostore";
+
     public FormStrings() {
         super();
     }
