@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,12 +59,13 @@ import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import com.openexchange.publish.PublicationService;
 import com.openexchange.publish.microformats.ContactPictureServlet;
+import com.openexchange.publish.microformats.FormStrings;
 import com.openexchange.publish.microformats.InfostoreFileServlet;
 import com.openexchange.publish.microformats.MicroformatServlet;
 import com.openexchange.publish.microformats.OXMFPublicationService;
 import com.openexchange.publish.microformats.tools.ContactTemplateUtils;
 import com.openexchange.publish.microformats.tools.InfostoreTemplateUtils;
-import com.openexchange.templating.TemplateService;
+import com.openexchange.templating.base.TemplateService;
 
 public class PublicationServicesActivator implements BundleActivator {
 
@@ -78,7 +79,7 @@ public class PublicationServicesActivator implements BundleActivator {
         contactPublisher = new OXMFPublicationService();
         contactPublisher.setFolderType("contacts");
         contactPublisher.setRootURL("/publications/contacts");
-        contactPublisher.setTargetDisplayName("OXMF Contacts");
+        contactPublisher.setTargetDisplayName(FormStrings.TARGET_NAME_CONTACTS);
         contactPublisher.setTargetId("com.openexchange.publish.microformats.contacts.online");
         contactPublisher.setDefaultTemplateName("contacts.tmpl");
         
@@ -93,7 +94,7 @@ public class PublicationServicesActivator implements BundleActivator {
         infostorePublisher = new OXMFPublicationService();
         infostorePublisher.setFolderType("infostore");
         infostorePublisher.setRootURL("/publications/infostore");
-        infostorePublisher.setTargetDisplayName("OXMF Infostore");
+        infostorePublisher.setTargetDisplayName(FormStrings.TARGET_NAME_INFOSTORE);
         infostorePublisher.setTargetId("com.openexchange.publish.microformats.infostore.online");
         infostorePublisher.setDefaultTemplateName("infostore.tmpl");
         InfostoreFileServlet.setInfostorePublisher(infostorePublisher);
